@@ -7,7 +7,7 @@ The specifications are responsible for sanitation, validation and normalisation.
 
 from input_algorithms.spec_base import (
       formatted, defaulted, any_spec, dictionary_spec, dictof, listof, required
-    , string_spec, overridden, boolean, file_spec, optional_spec, integer_spec
+    , string_spec, overridden, boolean, file_spec, optional_spec, integer_spec, or_spec
     , valid_string_spec, create_spec, string_choice_spec, filename_spec as orig_filename_spec
     )
 
@@ -29,7 +29,8 @@ class filename_spec(orig_filename_spec):
         return super(filename_spec, self).normalise_filled(meta, val)
 
 class Bespin(dictobj):
-    fields = ["dry_run", "flat", "config", "chosen_stack", "chosen_task", "extra", "interactive", "region", "environment"]
+    fields = ["dry_run", "assume_role", "flat", "config", "chosen_stack", "chosen_task", "extra", "interactive",
+              "region", "environment"]
 
 class Environment(dictobj):
     fields = ["account_id", "vars"]
@@ -66,7 +67,7 @@ class BespinSpec(object):
         return dictof(
               string_spec()
             , create_spec(Environment
-                , account_id = required(valid_string_spec(validators.regexed("\d+")))
+                , account_id = required(or_spec(string_spec(), valid_string_spec(validators.regexed("\d+"))))
                 , vars = dictionary_spec()
                 )
             )
@@ -84,14 +85,18 @@ class BespinSpec(object):
 
             , env = listof(stack_specs.env_spec(), expect=stack_objs.Environment)
 
+            , tags = dictionary_spec()
+
             , stack_json = filename_spec(formatted(defaulted(string_spec(), "{config_root}/{_key_name_1}.json"), formatter=MergedOptionStringFormatter))
-            , params_json = filename_spec(formatted(defaulted(string_spec(), "{config_root}/{environment}/{_key_name_1}-params.json"), formatter=MergedOptionStringFormatter))
+            , params_json = optional_spec(filename_spec(formatted(defaulted(string_spec(), "{config_root}/{environment}/{_key_name_1}-params.json"), formatter=MergedOptionStringFormatter)))
 
             , build_after = listof(formatted(string_spec(), formatter=MergedOptionStringFormatter))
             , ignore_deps = defaulted(boolean(), False)
 
             , vars = dictof(string_spec(), stack_specs.var_spec())
 
+            , skip_update_if_equivalent = listof(stack_specs.skipper_spec())
+
             , artifacts = dictof(string_spec(), create_spec(artifact_objs.Artifact
                 , compression_type = string_choice_spec(["gz", "xz"])
                 , history_length = integer_spec()
@@ -115,6 +120,8 @@ class BespinSpec(object):
         return create_spec(Bespin
             , config = file_spec()
 
+            , assume_role = optional_spec(string_spec())
+
             , dry_run = defaulted(boolean(), False)
             , flat = defaulted(boolean(), False)
             , environment = optional_spec(string_spec())
